Package: debrowser
Type: Package
Title: Interactive Differential Expresion Analysis Browser
Version: 1.38.0
Date: 2020-12-07
Author: Alper Kucukural <alper.kucukural@umassmed.edu>,
        Onur Yukselen <onur.yukselen@umassmed.edu>,
        Manuel Garber <manuel.garber@umassmed.edu>
Maintainer: Alper Kucukural <alper.kucukural@umassmed.edu>
Description: Bioinformatics platform containing interactive plots and tables
    for differential gene and region expression studies. Allows visualizing
    expression data much more deeply in an interactive and faster way. By
    changing the parameters, users can easily discover different parts of the
    data that like never have been done before. Manually creating and looking
    these plots takes time. With DEBrowser users can prepare plots without
    writing any code. Differential expression, PCA and clustering analysis are
    made on site and the results are shown in various plots such as scatter,
    bar, box, volcano, ma plots and Heatmaps.
Depends: R (>= 3.5.0),
License: GPL-3 + file LICENSE
Imports: shiny, jsonlite, shinyjs, shinydashboard, shinyBS, gplots, DT,
        ggplot2, RColorBrewer, annotate, AnnotationDbi, DESeq2, DOSE,
        igraph, grDevices, graphics, stats, utils, GenomicRanges,
        IRanges, S4Vectors, SummarizedExperiment, stringi, reshape2,
        org.Hs.eg.db, org.Mm.eg.db, limma, edgeR, clusterProfiler,
        methods, sva, RCurl, enrichplot, colourpicker, plotly,
        heatmaply, Harman, pathview, apeglm, ashr
RoxygenNote: 7.2.3
Encoding: UTF-8
Suggests: testthat, rmarkdown, knitr
VignetteBuilder: knitr, rmarkdown
URL: https://github.com/UMMS-Biocore/debrowser
BugReports: https://github.com/UMMS-Biocore/debrowser/issues/new
biocViews: Sequencing, ChIPSeq, RNASeq, DifferentialExpression,
        GeneExpression, Clustering, ImmunoOncology
git_url: https://git.bioconductor.org/packages/debrowser
git_branch: RELEASE_3_22
git_last_commit: 5dcc10b
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:30:06 UTC; biocbuild
