# Generated by roxygen2: do not edit by hand

export(BoxMainPlotControlsUI)
export(IQRPlotControlsUI)
export(actionButtonDE)
export(addDataCols)
export(addID)
export(all2all)
export(all2allControlsUI)
export(applyFilters)
export(applyFiltersNew)
export(applyFiltersToMergedComparison)
export(barMainPlotControlsUI)
export(batchEffectUI)
export(batchMethod)
export(changeClusterOrder)
export(checkCountData)
export(checkMetaData)
export(clustFunParamsUI)
export(clusterData)
export(compareClust)
export(condSelectUI)
export(correctCombat)
export(correctHarman)
export(customColorsUI)
export(cutOffSelectionUI)
export(dataLCFUI)
export(dataLoadUI)
export(deServer)
export(deUI)
export(debrowserIQRplot)
export(debrowserall2all)
export(debrowserbarmainplot)
export(debrowserbatcheffect)
export(debrowserboxmainplot)
export(debrowsercondselect)
export(debrowserdataload)
export(debrowserdeanalysis)
export(debrowserdensityplot)
export(debrowserheatmap)
export(debrowserhistogram)
export(debrowserlowcountfilter)
export(debrowsermainplot)
export(debrowserpcaplot)
export(dendControlsUI)
export(densityPlotControlsUI)
export(distFunParamsUI)
export(drawKEGG)
export(drawPCAExplained)
export(fileTypes)
export(fileUploadBox)
export(generateTestData)
export(getAfterLoadMsg)
export(getAll2AllPlotUI)
export(getBSTableUI)
export(getBarMainPlot)
export(getBarMainPlotUI)
export(getBoxMainPlot)
export(getBoxMainPlotUI)
export(getColorShapeSelection)
export(getColors)
export(getCompSelection)
export(getCondMsg)
export(getConditionSelector)
export(getConditionSelectorFromMeta)
export(getCovariateDetails)
export(getCutOffSelection)
export(getDEAnalysisText)
export(getDEResultsUI)
export(getDataAssesmentText)
export(getDataForTables)
export(getDataPreparationText)
export(getDensityPlot)
export(getDensityPlotUI)
export(getDomains)
export(getDown)
export(getDownloadSection)
export(getEnrichDO)
export(getEnrichGO)
export(getEnrichKEGG)
export(getEntrezIds)
export(getEntrezTable)
export(getGOLeftMenu)
export(getGOPlots)
export(getGSEA)
export(getGeneList)
export(getGeneSetData)
export(getGoPanel)
export(getGroupSelector)
export(getHeatmapUI)
export(getHelpButton)
export(getHideLegendOnOff)
export(getHistogramUI)
export(getIQRPlot)
export(getIQRPlotUI)
export(getIntroText)
export(getJSLine)
export(getKEGGModal)
export(getLeftMenu)
export(getLegendColors)
export(getLegendRadio)
export(getLegendSelect)
export(getLevelOrder)
export(getLoadingMsg)
export(getLogo)
export(getMainPanel)
export(getMainPlotUI)
export(getMainPlotsLeftMenu)
export(getMean)
export(getMergedComparison)
export(getMetaSelector)
export(getMethodDetails)
export(getMostVariedList)
export(getNormalizedMatrix)
export(getOrganism)
export(getOrganismBox)
export(getOrganismPathway)
export(getPCAPlotUI)
export(getPCAcontolUpdatesJS)
export(getPCAexplained)
export(getPCselection)
export(getPlotArea)
export(getProgramTitle)
export(getQAText)
export(getQCLeftMenu)
export(getQCPanel)
export(getSampleDetails)
export(getSampleNames)
export(getSearchData)
export(getSelHeat)
export(getSelectInputBox)
export(getSelectedCols)
export(getSelectedDatasetInput)
export(getShapeColor)
export(getStartPlotsMsg)
export(getStartupMsg)
export(getTabUpdateJS)
export(getTableDetails)
export(getTableModal)
export(getTableStyle)
export(getUp)
export(getUpDown)
export(getVariationData)
export(get_conditions_given_selection)
export(heatmapControlsUI)
export(heatmapJScode)
export(heatmapServer)
export(heatmapUI)
export(hideObj)
export(histogramControlsUI)
export(installpack)
export(kmeansControlsUI)
export(lcfMetRadio)
export(loadpack)
export(mainPlotControlsUI)
export(mainScatterNew)
export(niceKmeans)
export(normalizationMethods)
export(palUI)
export(panel.cor)
export(panel.hist)
export(pcaPlotControlsUI)
export(plotData)
export(plotMarginsUI)
export(plotSizeMarginsUI)
export(plotSizeUI)
export(plotTypeUI)
export(plot_pca)
export(prepDataContainer)
export(prepGroup)
export(prepHeatData)
export(prepPCADat)
export(push)
export(removeCols)
export(removeExtraCols)
export(round_vals)
export(runDE)
export(runDESeq2)
export(runEdgeR)
export(runHeatmap)
export(runHeatmap2)
export(runLimma)
export(run_pca)
export(selectConditions)
export(selectGroupInfo)
export(selectedInput)
export(sepRadio)
export(setBatch)
export(showObj)
export(startDEBrowser)
export(startHeatmap)
export(textareaInput)
export(togglePanels)
import(RColorBrewer)
import(apeglm)
import(ashr)
import(colourpicker)
import(heatmaply)
import(org.Hs.eg.db)
import(org.Mm.eg.db)
import(shinyBS)
importFrom(DESeq2,DESeq)
importFrom(DESeq2,DESeqDataSetFromMatrix)
importFrom(DESeq2,counts)
importFrom(DESeq2,estimateSizeFactors)
importFrom(DESeq2,lfcShrink)
importFrom(DESeq2,results)
importFrom(DOSE,enrichDO)
importFrom(DT,dataTableOutput)
importFrom(DT,datatable)
importFrom(DT,formatRound)
importFrom(DT,formatStyle)
importFrom(DT,renderDataTable)
importFrom(DT,styleInterval)
importFrom(Harman,harman)
importFrom(Harman,reconstructData)
importFrom(RCurl,getURL)
importFrom(annotate,geneSymbols)
importFrom(clusterProfiler,bitr)
importFrom(clusterProfiler,compareCluster)
importFrom(clusterProfiler,enrichGO)
importFrom(clusterProfiler,enrichKEGG)
importFrom(clusterProfiler,gseGO)
importFrom(edgeR,DGEList)
importFrom(edgeR,calcNormFactors)
importFrom(edgeR,equalizeLibSizes)
importFrom(edgeR,estimateCommonDisp)
importFrom(edgeR,exactTest)
importFrom(edgeR,glmFit)
importFrom(edgeR,glmLRT)
importFrom(edgeR,topTags)
importFrom(enrichplot,dotplot)
importFrom(enrichplot,gseaplot)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,ylab)
importFrom(gplots,bluered)
importFrom(gplots,heatmap.2)
importFrom(gplots,redblue)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,barplot)
importFrom(graphics,hist)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(igraph,layout.kamada.kawai)
importFrom(jsonlite,fromJSON)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,topTable)
importFrom(limma,voom)
importFrom(methods,new)
importFrom(pathview,pathview)
importFrom(plotly,"%>%")
importFrom(plotly,add_bars)
importFrom(plotly,event_data)
importFrom(plotly,ggplotly)
importFrom(plotly,group_by)
importFrom(plotly,hide_legend)
importFrom(plotly,plot_ly)
importFrom(plotly,plotlyOutput)
importFrom(plotly,renderPlotly)
importFrom(reshape2,melt)
importFrom(shiny,HTML)
importFrom(shiny,NS)
importFrom(shiny,a)
importFrom(shiny,actionButton)
importFrom(shiny,actionLink)
importFrom(shiny,addResourcePath)
importFrom(shiny,br)
importFrom(shiny,callModule)
importFrom(shiny,checkboxGroupInput)
importFrom(shiny,checkboxInput)
importFrom(shiny,column)
importFrom(shiny,conditionalPanel)
importFrom(shiny,div)
importFrom(shiny,downloadButton)
importFrom(shiny,downloadHandler)
importFrom(shiny,enableBookmarking)
importFrom(shiny,eventReactive)
importFrom(shiny,fileInput)
importFrom(shiny,fluidPage)
importFrom(shiny,fluidRow)
importFrom(shiny,h2)
importFrom(shiny,h3)
importFrom(shiny,h4)
importFrom(shiny,helpText)
importFrom(shiny,htmlOutput)
importFrom(shiny,icon)
importFrom(shiny,imageOutput)
importFrom(shiny,img)
importFrom(shiny,incProgress)
importFrom(shiny,isolate)
importFrom(shiny,mainPanel)
importFrom(shiny,need)
importFrom(shiny,numericInput)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,onBookmark)
importFrom(shiny,onBookmarked)
importFrom(shiny,onRestore)
importFrom(shiny,onRestored)
importFrom(shiny,outputOptions)
importFrom(shiny,p)
importFrom(shiny,parseQueryString)
importFrom(shiny,plotOutput)
importFrom(shiny,radioButtons)
importFrom(shiny,reactive)
importFrom(shiny,reactiveVal)
importFrom(shiny,reactiveValues)
importFrom(shiny,reactiveValuesToList)
importFrom(shiny,renderImage)
importFrom(shiny,renderPlot)
importFrom(shiny,renderPrint)
importFrom(shiny,renderTable)
importFrom(shiny,renderText)
importFrom(shiny,renderUI)
importFrom(shiny,runApp)
importFrom(shiny,selectInput)
importFrom(shiny,selectizeInput)
importFrom(shiny,shinyApp)
importFrom(shiny,shinyServer)
importFrom(shiny,shinyUI)
importFrom(shiny,showNotification)
importFrom(shiny,sidebarLayout)
importFrom(shiny,sidebarPanel)
importFrom(shiny,sliderInput)
importFrom(shiny,stopApp)
importFrom(shiny,strong)
importFrom(shiny,tabPanel)
importFrom(shiny,tableOutput)
importFrom(shiny,tabsetPanel)
importFrom(shiny,tags)
importFrom(shiny,textInput)
importFrom(shiny,textOutput)
importFrom(shiny,titlePanel)
importFrom(shiny,uiOutput)
importFrom(shiny,updateCheckboxInput)
importFrom(shiny,updateQueryString)
importFrom(shiny,updateSelectInput)
importFrom(shiny,updateTabsetPanel)
importFrom(shiny,updateTextInput)
importFrom(shiny,validate)
importFrom(shiny,verbatimTextOutput)
importFrom(shiny,wellPanel)
importFrom(shiny,withMathJax)
importFrom(shiny,withProgress)
importFrom(shinydashboard,dashboardBody)
importFrom(shinydashboard,dashboardHeader)
importFrom(shinydashboard,dashboardPage)
importFrom(shinydashboard,dashboardSidebar)
importFrom(shinydashboard,dropdownMenu)
importFrom(shinydashboard,menuItem)
importFrom(shinydashboard,menuSubItem)
importFrom(shinydashboard,messageItem)
importFrom(shinydashboard,sidebarMenu)
importFrom(shinydashboard,tabItem)
importFrom(shinydashboard,tabItems)
importFrom(shinydashboard,updateTabItems)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(shinyjs,extendShinyjs)
importFrom(shinyjs,hide)
importFrom(shinyjs,inlineCSS)
importFrom(shinyjs,js)
importFrom(shinyjs,onclick)
importFrom(shinyjs,show)
importFrom(shinyjs,useShinyjs)
importFrom(stats,aggregate)
importFrom(stats,as.dendrogram)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,cov)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,kmeans)
importFrom(stats,mahalanobis)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,prcomp)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(stringi,stri_rand_strings)
importFrom(sva,ComBat)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
importFrom(utils,packageDescription)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,update.packages)
importFrom(utils,write.table)
importMethodsFrom(AnnotationDbi,as.data.frame)
importMethodsFrom(AnnotationDbi,as.list)
importMethodsFrom(AnnotationDbi,colnames)
importMethodsFrom(AnnotationDbi,exists)
importMethodsFrom(AnnotationDbi,head)
importMethodsFrom(AnnotationDbi,keys)
importMethodsFrom(AnnotationDbi,mapIds)
importMethodsFrom(AnnotationDbi,mappedkeys)
importMethodsFrom(AnnotationDbi,ncol)
importMethodsFrom(AnnotationDbi,nrow)
importMethodsFrom(AnnotationDbi,sample)
importMethodsFrom(AnnotationDbi,select)
importMethodsFrom(AnnotationDbi,subset)
importMethodsFrom(DOSE,summary)
importMethodsFrom(GenomicRanges,as.factor)
importMethodsFrom(GenomicRanges,setdiff)
importMethodsFrom(IRanges,"colnames<-")
importMethodsFrom(IRanges,"rownames<-")
importMethodsFrom(IRanges,as.matrix)
importMethodsFrom(IRanges,gsub)
importMethodsFrom(IRanges,lapply)
importMethodsFrom(IRanges,mean)
importMethodsFrom(IRanges,nchar)
importMethodsFrom(IRanges,paste)
importMethodsFrom(IRanges,rownames)
importMethodsFrom(IRanges,toupper)
importMethodsFrom(IRanges,unique)
importMethodsFrom(IRanges,which)
importMethodsFrom(S4Vectors,eval)
importMethodsFrom(S4Vectors,grep)
importMethodsFrom(S4Vectors,grepl)
importMethodsFrom(S4Vectors,levels)
importMethodsFrom(S4Vectors,sapply)
importMethodsFrom(S4Vectors,t)
importMethodsFrom(SummarizedExperiment,cbind)
importMethodsFrom(SummarizedExperiment,order)
importMethodsFrom(SummarizedExperiment,rbind)
