% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/help.R
\name{getIntroText}
\alias{getIntroText}
\title{getIntroText
Intro text}
\usage{
getIntroText()
}
\value{
the JS for tab updates
}
\description{
getIntroText
Intro text
}
\examples{
    x<- getIntroText()

}
