% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmap.R
\name{palUI}
\alias{palUI}
\title{palUI}
\usage{
palUI(id)
}
\arguments{
\item{id, }{namespace ID}
}
\value{
pals
}
\description{
get pallete
}
\note{
\code{palUI}
}
\examples{
    x <- palUI("heatmap")
}
