% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmap.R
\name{heatmapJScode}
\alias{heatmapJScode}
\title{heatmapJScode}
\usage{
heatmapJScode()
}
\value{
JS Code
}
\description{
heatmap JS code for selection functionality
}
\examples{
    x <- heatmapJScode()

}
