% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/uifuncs.R
\name{getGOLeftMenu}
\alias{getGOLeftMenu}
\title{getGOLeftMenu}
\usage{
getGOLeftMenu()
}
\value{
returns the left menu according to the selected tab;
}
\description{
Generates the GO Left menu to be displayed within the DEBrowser.
}
\note{
\code{getGOLeftMenu}
}
\examples{
    x <- getGOLeftMenu()
}
