% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/batcheffect.R
\name{correctCombat}
\alias{correctCombat}
\title{Correct Batch Effect using Combat in sva package}
\usage{
correctCombat(input = NULL, idata = NULL, metadata = NULL, method = NULL)
}
\arguments{
\item{input, }{input values}

\item{idata, }{data}

\item{metadata, }{metadata}

\item{method, }{method: either Combat or CombatSeq}
}
\value{
data
}
\description{
Batch effect correction
}
\examples{
    x<-correctCombat ()
}
