% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pca.R
\name{getHideLegendOnOff}
\alias{getHideLegendOnOff}
\title{getHideLegendOnOff}
\usage{
getHideLegendOnOff(id = "pca")
}
\arguments{
\item{id, }{namespace id}
}
\description{
hide legend
}
\examples{
    x <- getHideLegendOnOff("pca")
}
