% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/uifuncs.R
\name{removeExtraCols}
\alias{removeExtraCols}
\title{removeExtraCols}
\usage{
removeExtraCols(dat = NULL)
}
\arguments{
\item{dat, }{selected data}
}
\description{
remove extra columns for QC plots
}
\examples{
    removeExtraCols()


}
