% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/funcs.R
\name{getTabUpdateJS}
\alias{getTabUpdateJS}
\title{getTabUpdateJS
prepmenu tab and discovery menu tab updates}
\usage{
getTabUpdateJS()
}
\value{
the JS for tab updates
}
\description{
getTabUpdateJS
prepmenu tab and discovery menu tab updates
}
\examples{
    x<- getTabUpdateJS()

}
